@@ -191,6 +191,7 @@ class AkonadiModel : public Akonadi::EntityTreeModel
          *  create/delete/change rights and compatible with the current KAlarm
          *  calendar format.
          *
+         *  @param collection The collection to be inspected
          *  @param format  Updated to contain the backend calendar storage format.
          *                 If read-only, = KACalendar::Current;
          *                 if unknown format, = KACalendar::Incompatible;
@@ -200,7 +201,7 @@ class AkonadiModel : public Akonadi::EntityTreeModel
          *         -1 = read-only (if @p compat == KACalendar::Current), or
          *              incompatible format otherwise.
          */
-        static int isWritable(const Akonadi::Collection&, KACalendar::Compat& format);
+        static int isWritable(const Akonadi::Collection& collection, KACalendar::Compat& format);
 
         static CalEvent::Types types(const Akonadi::Collection&);
 
@@ -210,11 +211,14 @@ class AkonadiModel : public Akonadi::EntityTreeModel
         /** Signal emitted when a collection has been added to the model. */
         void collectionAdded(const Akonadi::Collection&);
 
-        /** Signal emitted when a collection's enabled or read-only status has changed.
+        /** Signal emitted when a collection's enabled, read-only or alarm types
+         *  status has changed.
+         *  @param change    The type of status which has changed
+         *  @param newValue  The new value of the status that has changed
          *  @param inserted  true if the reason for the change is that the collection
          *                   has been inserted into the model
          */
-        void collectionStatusChanged(const Akonadi::Collection&, AkonadiModel::Change, const QVariant& newValue, bool inserted);
+        void collectionStatusChanged(const Akonadi::Collection&, AkonadiModel::Change change, const QVariant& newValue, bool inserted);
 
         /** Signal emitted when events have been added to the model. */
         void eventsAdded(const AkonadiModel::EventList&);
@@ -229,20 +233,20 @@ class AkonadiModel : public Akonadi::EntityTreeModel
          *  @param id      Akonadi ID for the collection
          *  @param status  true if successful, false if error
          */
-        void collectionModified(Akonadi::Collection::Id, bool status = true);
+        void collectionModified(Akonadi::Collection::Id id, bool status = true);
 
         /** Signal emitted when Akonadi has completed a collection deletion.
          *  @param id      Akonadi ID for the collection
          *  @param status  true if successful, false if error
          */
-        void collectionDeleted(Akonadi::Collection::Id, bool status = true);
+        void collectionDeleted(Akonadi::Collection::Id id, bool status = true);
 
         /** Signal emitted when Akonadi has completed an item creation, update
          *  or deletion.
          *  @param id      Akonadi ID for the item
          *  @param status  true if successful, false if error
          */
-        void itemDone(Akonadi::Item::Id, bool status = true);
+        void itemDone(Akonadi::Item::Id id, bool status = true);
 
         /** Signal emitted when calendar migration/creation has completed. */
         void migrationCompleted();
